Overview: module code — hepstats 0.2.1 documentation

# All modules for which code is available

- hepstats.hypotests.calculators.asymptotic_calculator
- hepstats.hypotests.calculators.basecalculator
- hepstats.hypotests.calculators.frequentist_calculator
- hepstats.hypotests.core.confidence_interval
- hepstats.hypotests.core.discovery
- hepstats.hypotests.core.upperlimit
- hepstats.hypotests.hypotests_object
- hepstats.hypotests.parameters
- hepstats.modeling.bayesian_blocks
- hepstats.splot.sweights